@@ -13,20 +13,18 @@
 #    under the License.
 
 import copy
+
 import mock
-from webob import exc
-import webtest
-
-from neutron_lib import constants as const
-from oslo_utils import uuidutils
-
 from neutron.api.v2 import resource as api_res_log
 from neutron.common import config
 from neutron import manager
 from neutron.notifiers import nova as nova_log
-
 from neutron.tests.unit.api.v2 import test_base as test_api_v2
 from neutron.tests.unit.extensions import base as test_api_v2_extension
+from neutron_lib import constants as const
+from oslo_utils import uuidutils
+from webob import exc
+import webtest
 
 from networking_sfc.extensions import flowclassifier as fc_ext
 
@@ -43,7 +41,7 @@ class FlowClassifierExtensionTestCase(
     fmt = 'json'
 
     def setUp(self):
-        self._mock_unncessary_logging()
+        self._mock_unnecessary_logging()
         super(FlowClassifierExtensionTestCase, self).setUp()
         self._setUpExtension(
             'networking_sfc.extensions.flowclassifier.'
@@ -55,7 +53,7 @@ class FlowClassifierExtensionTestCase(
             plural_mappings={}
         )
 
-    def _mock_unncessary_logging(self):
+    def _mock_unnecessary_logging(self):
         mock_log_cfg_p = mock.patch.object(config, 'LOG')
         self.mock_log_cfg = mock_log_cfg_p.start()
 
@@ -90,6 +88,7 @@ class FlowClassifierExtensionTestCase(
             'name': data['flow_classifier'].get('name') or '',
             'description': data['flow_classifier'].get('description') or '',
             'tenant_id': data['flow_classifier']['tenant_id'],
+            'project_id': data['flow_classifier']['project_id'],
             'source_port_range_min': source_port_range_min,
             'source_port_range_max': source_port_range_max,
             'destination_port_range_min': destination_port_range_min,
@@ -112,9 +111,10 @@ class FlowClassifierExtensionTestCase(
 
     def test_create_flow_classifier(self):
         flowclassifier_id = _uuid()
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'logical_source_port': _uuid(),
-            'tenant_id': _uuid(),
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         expected_data = self._get_expected_flow_classifier(data)
         return_value = copy.copy(expected_data['flow_classifier'])
@@ -137,11 +137,12 @@ class FlowClassifierExtensionTestCase(
         for source_port_range_min in [None, 100, '100']:
             for source_port_range_max in [None, 200, '200']:
                 flowclassifier_id = _uuid()
+                tenant_id = _uuid()
                 data = {'flow_classifier': {
                     'source_port_range_min': source_port_range_min,
                     'source_port_range_max': source_port_range_max,
                     'logical_source_port': _uuid(),
-                    'tenant_id': _uuid(),
+                    'tenant_id': tenant_id, 'project_id': tenant_id,
                 }}
                 expected_data = self._get_expected_flow_classifier(data)
                 return_value = copy.copy(expected_data['flow_classifier'])
@@ -164,11 +165,12 @@ class FlowClassifierExtensionTestCase(
         for destination_port_range_min in [None, 100, '100']:
             for destination_port_range_max in [None, 200, '200']:
                 flowclassifier_id = _uuid()
+                tenant_id = _uuid()
                 data = {'flow_classifier': {
                     'destination_port_range_min': destination_port_range_min,
                     'destination_port_range_max': destination_port_range_max,
                     'logical_source_port': _uuid(),
-                    'tenant_id': _uuid(),
+                    'tenant_id': tenant_id, 'project_id': tenant_id,
                 }}
                 expected_data = self._get_expected_flow_classifier(data)
                 return_value = copy.copy(expected_data['flow_classifier'])
@@ -192,10 +194,11 @@ class FlowClassifierExtensionTestCase(
             None, '10.0.0.0/8'
         ]:
             flowclassifier_id = _uuid()
+            tenant_id = _uuid()
             data = {'flow_classifier': {
                 'source_ip_prefix': logical_source_ip_prefix,
                 'logical_source_port': _uuid(),
-                'tenant_id': _uuid(),
+                'tenant_id': tenant_id, 'project_id': tenant_id,
             }}
             expected_data = self._get_expected_flow_classifier(data)
             return_value = copy.copy(expected_data['flow_classifier'])
@@ -219,10 +222,11 @@ class FlowClassifierExtensionTestCase(
             None, '10.0.0.0/8'
         ]:
             flowclassifier_id = _uuid()
+            tenant_id = _uuid()
             data = {'flow_classifier': {
                 'destination_ip_prefix': logical_destination_ip_prefix,
                 'logical_source_port': _uuid(),
-                'tenant_id': _uuid(),
+                'tenant_id': tenant_id, 'project_id': tenant_id,
             }}
             expected_data = self._get_expected_flow_classifier(data)
             return_value = copy.copy(expected_data['flow_classifier'])
@@ -246,9 +250,10 @@ class FlowClassifierExtensionTestCase(
             None, _uuid()
         ]:
             flowclassifier_id = _uuid()
+            tenant_id = _uuid()
             data = {'flow_classifier': {
                 'logical_source_port': logical_source_port,
-                'tenant_id': _uuid(),
+                'tenant_id': tenant_id, 'project_id': tenant_id,
             }}
             expected_data = self._get_expected_flow_classifier(data)
             return_value = copy.copy(expected_data['flow_classifier'])
@@ -272,9 +277,10 @@ class FlowClassifierExtensionTestCase(
             None, _uuid()
         ]:
             flowclassifier_id = _uuid()
+            tenant_id = _uuid()
             data = {'flow_classifier': {
                 'logical_destination_port': logical_destination_port,
-                'tenant_id': _uuid(),
+                'tenant_id': tenant_id, 'project_id': tenant_id,
             }}
             expected_data = self._get_expected_flow_classifier(data)
             return_value = copy.copy(expected_data['flow_classifier'])
@@ -296,9 +302,10 @@ class FlowClassifierExtensionTestCase(
     def test_create_flow_classifier_l7_parameters(self):
         for l7_parameters in [None, {}]:
             flowclassifier_id = _uuid()
+            tenant_id = _uuid()
             data = {'flow_classifier': {
                 'logical_source_port': _uuid(),
-                'tenant_id': _uuid(),
+                'tenant_id': tenant_id, 'project_id': tenant_id,
                 'l7_parameters': l7_parameters
             }}
             expected_data = self._get_expected_flow_classifier(data)
@@ -321,9 +328,10 @@ class FlowClassifierExtensionTestCase(
     def test_create_flow_classifier_ethertype(self):
         for ethertype in [None, 'IPv4', 'IPv6']:
             flowclassifier_id = _uuid()
+            tenant_id = _uuid()
             data = {'flow_classifier': {
                 'logical_source_port': _uuid(),
-                'tenant_id': _uuid(),
+                'tenant_id': tenant_id, 'project_id': tenant_id,
                 'ethertype': ethertype
             }}
             expected_data = self._get_expected_flow_classifier(data)
@@ -349,9 +357,10 @@ class FlowClassifierExtensionTestCase(
             const.PROTO_NAME_ICMP
         ]:
             flowclassifier_id = _uuid()
+            tenant_id = _uuid()
             data = {'flow_classifier': {
                 'logical_source_port': _uuid(),
-                'tenant_id': _uuid(),
+                'tenant_id': tenant_id, 'project_id': tenant_id,
                 'protocol': protocol
             }}
             expected_data = self._get_expected_flow_classifier(data)
@@ -373,10 +382,11 @@ class FlowClassifierExtensionTestCase(
 
     def test_create_flow_classifier_all_fields(self):
         flowclassifier_id = _uuid()
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'name': 'test1',
             'description': 'desc',
-            'tenant_id': _uuid(),
+            'tenant_id': tenant_id, 'project_id': tenant_id,
             'source_port_range_min': 100,
             'source_port_range_max': 200,
             'destination_port_range_min': 100,
@@ -407,10 +417,11 @@ class FlowClassifierExtensionTestCase(
         self.assertEqual(return_value, res['flow_classifier'])
 
     def test_create_flow_classifier_invalid_l7_parameters(self):
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'logical_source_port': _uuid(),
             'l7_parameters': {'abc': 'def'},
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -420,10 +431,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_create_flow_classifier_invalid_protocol(self):
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'logical_source_port': _uuid(),
             'protocol': 'unknown',
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -433,10 +445,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_create_flow_classifier_invalid_ethertype(self):
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'logical_source_port': _uuid(),
             'ethertype': 'unknown',
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -446,10 +459,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_create_flow_classifier_port_small(self):
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'logical_source_port': _uuid(),
             'source_port_range_min': -1,
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -459,10 +473,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_create_flow_classifier_port_large(self):
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'logical_source_port': _uuid(),
             'source_port_range_min': 65536,
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -472,10 +487,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_create_flow_classifier_ip_prefix_no_cidr(self):
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'source_ip_prefix': '10.0.0.0',
             'logical_source_port': _uuid(),
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -485,10 +501,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_create_flow_classifier_ip_prefix_invalid_cidr(self):
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'source_ip_prefix': '10.0.0.0/33',
             'logical_source_port': _uuid(),
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -498,9 +515,10 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_create_flow_classifier_port_id_nouuid(self):
+        tenant_id = _uuid()
         data = {'flow_classifier': {
             'logical_source_port': 'unknown',
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -510,9 +528,10 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_list(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         return_value = [{
-            'tenant_id': _uuid(),
+            'tenant_id': tenant_id, 'project_id': tenant_id,
             'id': flowclassifier_id
         }]
         instance = self.plugin.return_value
@@ -532,6 +551,7 @@ class FlowClassifierExtensionTestCase(
         self.assertEqual(return_value, res['flow_classifiers'])
 
     def test_flow_classifier_list_all_fields(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         return_value = [{
             'name': 'abc',
@@ -547,7 +567,7 @@ class FlowClassifierExtensionTestCase(
             'logical_source_port': _uuid(),
             'logical_destination_port': _uuid(),
             'l7_parameters': {},
-            'tenant_id': _uuid(),
+            'tenant_id': tenant_id, 'project_id': tenant_id,
             'id': flowclassifier_id
         }]
         instance = self.plugin.return_value
@@ -565,11 +585,12 @@ class FlowClassifierExtensionTestCase(
         self.assertEqual(return_value, res['flow_classifiers'])
 
     def test_flow_classifier_list_unknown_fields(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         return_value = [{
             'logical_source_port': _uuid(),
             'new_key': 'value',
-            'tenant_id': _uuid(),
+            'tenant_id': tenant_id, 'project_id': tenant_id,
             'id': flowclassifier_id
         }]
         expected_return = copy.copy(return_value)
@@ -590,10 +611,11 @@ class FlowClassifierExtensionTestCase(
         self.assertEqual(expected_return, res['flow_classifiers'])
 
     def test_flow_classifier_get(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         return_value = {
             'logical_source_port': _uuid(),
-            'tenant_id': _uuid(),
+            'tenant_id': tenant_id, 'project_id': tenant_id,
             'id': flowclassifier_id
         }
         instance = self.plugin.return_value
@@ -615,13 +637,14 @@ class FlowClassifierExtensionTestCase(
         self.assertEqual(return_value, res['flow_classifier'])
 
     def test_flow_classifier_update(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         update_data = {'flow_classifier': {
             'name': 'new_name',
             'description': 'new_desc',
         }}
         return_value = {
-            'tenant_id': _uuid(),
+            'tenant_id': tenant_id, 'project_id': tenant_id,
             'id': flowclassifier_id
         }
 
@@ -642,10 +665,11 @@ class FlowClassifierExtensionTestCase(
         self.assertEqual(return_value, res['flow_classifier'])
 
     def test_flow_classifier_update_source_port_range_min(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'source_port_range_min': 100,
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -656,10 +680,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_source_port_range_max(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'source_port_range_max': 100,
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -670,10 +695,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_destination_port_range_min(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'destination_port_range_min': 100,
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -684,10 +710,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_destination_port_range_max(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'destination_port_range_max': 100,
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -698,10 +725,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_source_ip_prefix(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'source_ip_prefix': '10.0.0.0/8',
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -712,10 +740,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_destination_ip_prefix(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'destination_ip_prefix': '10.0.0.0/8',
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -726,10 +755,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_logical_source_port(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'logical_source_port': _uuid(),
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -740,10 +770,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_logical_destination_port(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'logical_destination_port': _uuid(),
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -754,10 +785,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_ethertype(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'ethertype': None,
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -768,10 +800,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_protocol(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'protococol': None,
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
@@ -782,10 +815,11 @@ class FlowClassifierExtensionTestCase(
             content_type='application/%s' % self.fmt)
 
     def test_flow_classifier_update_l7_parameters(self):
+        tenant_id = _uuid()
         flowclassifier_id = _uuid()
         data = {'flow_classifier': {
             'l7_parameters': {},
-            'tenant_id': _uuid()
+            'tenant_id': tenant_id, 'project_id': tenant_id,
         }}
         self.assertRaises(
             webtest.app.AppError,
